diff scripts/gui/uitoggletool.m @ 19867:9fc020886ae9

maint: Clean up m-files to follow Octave coding conventions. Try to trim long lines to < 80 chars. Use '##' for single line comments. Use '(...)' around tests for if/elseif/switch/while. Abut cell indexing operator '{' next to variable. Abut array indexing operator '(' next to variable. Use space between negation operator '!' and following expression. Use two newlines between endfunction and start of %!test or %!demo code. Remove unnecessary parens grouping between short-circuit operators. Remove stray extra spaces (typos) between variables and assignment operators. Remove stray extra spaces from ends of lines.
author Rik <rik@octave.org>
date Mon, 23 Feb 2015 14:54:39 -0800
parents 4197fc428c7d
children 7890893a0e69
line wrap: on
line diff
--- a/scripts/gui/uitoggletool.m	Mon Feb 23 16:42:25 2015 +0000
+++ b/scripts/gui/uitoggletool.m	Mon Feb 23 14:54:39 2015 -0800
@@ -17,15 +17,16 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {@var{handle} =} uitoggletool ("Name", value, @dots{})
 ## @deftypefnx {Function File} {@var{handle} =} uitoggletool (@var{parent}, "Name", value, @dots{})
 ## @end deftypefn
 
 ## Author: goffioul
 
-function handle = uitoggletool (varargin)
+function hui = uitoggletool (varargin)
 
-  [h, args] = __uiobject_split_args__ ("uitoggletool", varargin, {"uitoolbar"}, 0);
+  [h, args] = __uiobject_split_args__ ("uitoggletool", varargin,
+                                       {"uitoolbar"}, 0);
   if (isempty (h))
     h = findobj (gcf, "-depth", 1, "type", "uitoolbar");
     if (isempty (h))
@@ -34,7 +35,7 @@
       h = h(1);
     endif
   endif
-  handle = __go_uitoggletool__ (h, args{:});
+  hui = __go_uitoggletool__ (h, args{:});
 
 endfunction
@@ -17,15 +17,16 @@
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{handle} =} uitoggletool ("Name", value, @dots{})
-## @deftypefnx {Function File} {@var{handle} =} uitoggletool (@var{parent}, "Name", value, @dots{})
+## @deftypefn  {Function File} {@var{hui} =} uitoggletool ("Name", value, @dots{})
+## @deftypefnx {Function File} {@var{hui} =} uitoggletool (@var{parent}, "Name", value, @dots{})
 ## @end deftypefn
 